==> aliyun-python-sdk-alb-1.0.3.tar.gz: aliyun-python-sdk-alb-1.0.3/aliyunsdkalb/request/v20200616/ListHealthCheckTemplatesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalb.endpoint import endpoint_data

class ListHealthCheckTemplatesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Alb', '2020-06-16', 'ListHealthCheckTemplates','alb')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_HealthCheckTemplateNames(self): # Array
		return self.get_query_params().get('HealthCheckTemplateNames')

	def set_HealthCheckTemplateNames(self, HealthCheckTemplateNames):  # Array
		for index1, value1 in enumerate(HealthCheckTemplateNames):
			self.add_query_param('HealthCheckTemplateNames.' + str(index1 + 1) + '.HealthCheckTemplateNames', value1)
	def get_MaxResults(self): # Integer
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self, MaxResults):  # Integer
		self.add_query_param('MaxResults', MaxResults)
	def get_HealthCheckTemplateIds(self): # Array
		return self.get_query_params().get('HealthCheckTemplateIds')

	def set_HealthCheckTemplateIds(self, HealthCheckTemplateIds):  # Array
		for index1, value1 in enumerate(HealthCheckTemplateIds):
			self.add_query_param('HealthCheckTemplateIds.' + str(index1 + 1) + '.HealthCheckTemplateIds', value1)

==> aliyun-python-sdk-alb-1.0.8.tar.gz: aliyun-python-sdk-alb-1.0.8/aliyunsdkalb/request/v20200616/ListHealthCheckTemplatesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkalb.endpoint import endpoint_data

class ListHealthCheckTemplatesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Alb', '2020-06-16', 'ListHealthCheckTemplates','alb')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_HealthCheckTemplateNames(self): # Array
		return self.get_query_params().get('HealthCheckTemplateNames')

	def set_HealthCheckTemplateNames(self, HealthCheckTemplateNames):  # Array
		for index1, value1 in enumerate(HealthCheckTemplateNames):
			self.add_query_param('HealthCheckTemplateNames.' + str(index1 + 1), value1)
	def get_MaxResults(self): # Integer
		return self.get_query_params().get('MaxResults')

	def set_MaxResults(self, MaxResults):  # Integer
		self.add_query_param('MaxResults', MaxResults)
	def get_HealthCheckTemplateIds(self): # Array
		return self.get_query_params().get('HealthCheckTemplateIds')

	def set_HealthCheckTemplateIds(self, HealthCheckTemplateIds):  # Array
		for index1, value1 in enumerate(HealthCheckTemplateIds):
			self.add_query_param('HealthCheckTemplateIds.' + str(index1 + 1), value1)
